@@ -499,6 +499,10 @@ public:
     SshMasterConnection* findServerSshConnection(QString host);
 
     void showHelp();
+    void showVersion();
+    void showTextFile(QString file, QString title);
+    void showGit();
+    void showChangelog();
     void showHelpPack();
     void exportDirs ( QString exports,bool removable=false );
     void reloadUsers();
@@ -537,6 +541,7 @@ private:
     QStringList _transApplicationsNames;
     QString portableDataPath;
     QString proxyErrString;
+    bool haveTerminal;
     bool proxyRunning;
     bool drawMenu;
     bool extStarted;
@@ -768,6 +773,9 @@ private:
     bool winSshdStarted;
     static QString u3Device;
 
+    QString pulseVersionTestOutput;
+    QProcess* pulseVersionTest;
+    bool pulseVersionIsLegacy;
     QProcess* pulseServer;
     QStringList pulseArgs;
     QTimer* pulseTimer;
@@ -793,6 +801,7 @@ private:
     QString lastFreeServer;
     QString cardLogin;
     QTextEdit* stInfo;
+    int localDisplayNumber;
 
     SVGFrame* ln;
     int tunnel;
@@ -962,6 +971,7 @@ public slots:
     void slotEmbedControlAction();
     void slotDetachProxyWindow();
     void slotActivateWindow();
+    void setFocus();
 
 private slots:
     void slotSnameChanged ( const QString& );
@@ -1064,6 +1074,12 @@ private slots:
     void slotReconnectSession();
     void slotStartBroker();
     void slotStartNewBrokerSession ();
+#ifdef Q_OS_DARWIN
+    void slotSetModMap();
+private:
+    QTimer* modMapTimer;
+    QString kbMap;
+#endif
 
 private:
     void resizeProxyWinOnDisplay(int display);
